---
title: <span class="badge object-type-scalar"></span> Pebibytes
---
# <span class="badge object-type-scalar"></span> Pebibytes

Data: pebibytes

## Definition

```python
# Data: pebibytes
Pebibytes: typing.Literal["pbytes"] = "pbytes"
```
